[![Build Status](https://travis-ci.com/danaraujocr/trendfitter.svg?branch=master)](https://travis-ci.com/github/danaraujocr/trendfitter)

# trendfitter
A convenient python library for multivariate statistic modeling research and application
